@@ -1,4 +1,4 @@
-// Copyright (C) 2018 Iñaki Ucar
+// Copyright (C) 2018-2023 Iñaki Ucar
 //
 // This file is part of simmer.
 //
@@ -39,7 +39,7 @@ namespace simmer {
       int i = 0;
 
       while (i++ != batch) {
-        if (time.size() <= count)
+        if (time.size() <= count || check_stop(time[count]))
           return;
         delay += time[count];
 
@@ -54,24 +54,19 @@ namespace simmer {
           arrival->order.set_preemptible(preemptible[count-1]);
         if (col_restart)
           arrival->order.set_restart(restart[count-1]);
-
-        // schedule the arrival
-        sim->schedule(delay, arrival,
-                      first_activity && first_activity->priority ?
-                        first_activity->priority : count);
       }
       // schedule the generator
       sim->schedule(delay, this, Source::priority);
     }
 
-    void set_source(const ANY& new_source) {
+    void set_source(const std::any& new_source) {
       if (new_source.type() != typeid(RData))
         Rcpp::stop("data frame required");
-      RData df = boost::any_cast<RData>(new_source);
+      RData df = std::any_cast<RData>(new_source);
 
       if (!df.containsElementNamed(col_time.c_str()))
         Rcpp::stop("column '%s' not present", col_time);
-      foreach_ (const std::string& col_attr, col_attrs) {
+      for (const auto& col_attr : col_attrs) {
         if (!df.containsElementNamed(col_attr.c_str()))
           Rcpp::stop("column '%s' not present", col_attr);
       }
@@ -85,7 +80,7 @@ namespace simmer {
       source = df;
       time = source[col_time];
       attrs.clear();
-      foreach_ (const std::string& col_attr, col_attrs)
+      for (const auto& col_attr : col_attrs)
         attrs.push_back(source[col_attr]);
       if (col_priority) priority = source[*col_priority];
       if (col_preemptible) preemptible = source[*col_preemptible];
